Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/ble_berrymed_pulse_oximeter_simpletest.py
    :caption: examples/ble_berrymed_pulse_oximeter_simpletest.py
    :linenos:
